using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;
using Microsoft.Xna.Framework.Net;
using Microsoft.Xna.Framework.Storage;

using XNACS1Lib;

namespace SpriteAnimation {
    public class Game1 : XNACS1Base {
        private XNACS1Rectangle rec;
        private ShowVector recfront;
        private ShowVector recnormal;

        private XNACS1Circle circ;
        private ShowVector circfront;
        private ShowVector circnormal;

        XNACS1Rectangle Hero;
        XNACS1Rectangle SomeDude, SomeOtherDude;

        protected override void InitializeWorld() {
            World.SetWorldCoordinate(Vector2.One, 100);
            World.SetWorldCoordinate(new Vector2(-World.WorldDimension.X / 2, -World.WorldDimension.Y / 2), 100);


            SomeDude = new XNACS1Rectangle(new Vector2(15, 15), 10, 10);
            SomeDude.SetTextureSpriteSheet("Sprites",   // file name
                                            13,         // columns
                                            16,         // rows
                                            0);         // paddings
            SomeDude.UseSpriteSheet = true;
            SomeDude.SetTextureSpriteAnimationFrames(8, 2,   // begin X/Y location
                                                     12, 2,  // end X/Y location
                                                     20,      // how many ticks per sprite frame
                                                     SpriteSheetAnimationMode.AnimateSwing);
            SomeDude.UseSpriteSheetAnimation = true;

            SomeOtherDude = new XNACS1Rectangle(new Vector2(-15, 15), 10, 10);
            SomeOtherDude.SetTextureSpriteSheet("Sprites", 13, 16, 0);
            SomeOtherDude.UseSpriteSheet = true;
            SomeOtherDude.SetTextureSpriteAnimationFrames(0, 0,   // begin x/y
                                                          12, 8,  // end x/y
                                                          3, SpriteSheetAnimationMode.AnimateBackward);
            SomeOtherDude.UseSpriteSheetAnimation = true;
            
            
            Hero = new XNACS1Rectangle(Vector2.Zero, 10, 10);
            Hero.SetTextureSpriteSheet("Sprites", 13, 16, 0); // 13 columns by 16 rows, zero padding
            Hero.UseSpriteSheet = true;
            Hero.SetTextureSpriteAnimationFrames(0, 6,  // begin x/y location
                                                 1, 6,  // end x/y location
                                                 1,     // how many ticks per sprite frame
                                                 SpriteSheetAnimationMode.AnimateForward);
            Hero.UseSpriteSheetAnimation = true;


            rec = new XNACS1Rectangle(new Vector2(-20, 10), 10, 5);
            circ = new XNACS1Circle(new Vector2(10, -20), 5);

            recfront = new ShowVector(rec.Center, rec.FrontDirection, Vector2.Zero, Vector2.Zero, 5);
            recnormal = new ShowVector(rec.Center, rec.NormalDirection, Vector2.Zero, Vector2.Zero, 5);

            circfront = new ShowVector(circ.Center, rec.FrontDirection, Vector2.Zero, Vector2.Zero, 5);
            circnormal = new ShowVector(circ.Center, rec.NormalDirection, Vector2.Zero, Vector2.Zero, 5);
        }

        protected override void UpdateWorld() {
            if (GamePad.ButtonBackClicked())
                Exit();

            rec.RotateAngle += 3;
            recfront.SetVectorDir(rec.FrontDirection);
            recnormal.SetVectorDir(rec.NormalDirection);

            circ.RotateAngle += -3;
            circfront.SetVectorDir(circ.FrontDirection);
            circnormal.SetVectorDir(circ.NormalDirection);

            if (GamePad.Dpad.Up == ButtonState.Pressed && (Hero.CurrentSpriteSheetFrameX < 0 || Hero.CurrentSpriteSheetFrameX > 1))
                Hero.SetTextureSpriteAnimationFrames(0, 0, 1, 0, 5, SpriteSheetAnimationMode.AnimateForward);
            else if (GamePad.Dpad.Down == ButtonState.Pressed && (Hero.CurrentSpriteSheetFrameX < 3 || Hero.CurrentSpriteSheetFrameX > 4))
                Hero.SetTextureSpriteAnimationFrames(3, 0, 4, 0, 5, SpriteSheetAnimationMode.AnimateForward);
            else if (GamePad.Dpad.Left == ButtonState.Pressed && (Hero.CurrentSpriteSheetFrameX < 6 || Hero.CurrentSpriteSheetFrameX > 7))
                Hero.SetTextureSpriteAnimationFrames(6, 0, 7, 0, 5, SpriteSheetAnimationMode.AnimateForward);
            else if (GamePad.Dpad.Right == ButtonState.Pressed && (Hero.CurrentSpriteSheetFrameX < 9 || Hero.CurrentSpriteSheetFrameX > 10))
                Hero.SetTextureSpriteAnimationFrames(9, 0, 10, 0, 5, SpriteSheetAnimationMode.AnimateForward);

            Hero.RotateAngle += GamePad.ThumbSticks.Left.X;

            if (GamePad.ButtonAClicked())
                Hero.UseSpriteSheet = !Hero.UseSpriteSheet;

            if (GamePad.ButtonBClicked())
                SomeDude.UseSpriteSheetAnimation = !SomeDude.UseSpriteSheetAnimation;
        }
    }
}
