using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;
using Microsoft.Xna.Framework.Net;
using Microsoft.Xna.Framework.Storage;

using XNACS1Lib;

namespace SpriteAnimation
{
    /// <summary>
    /// </summary>
    public class ShowVector 
    {
        private const float kVecWidth = 0.2f;
        private Color kVecColor = Color.Red;
        private Color kUVecColor = Color.LightBlue;
        private Color kVVecColor = Color.LightGreen;


        private XNACS1Rectangle mVec, mVecInU, mVecInV;
        private XNACS1Circle mStart;
        private Vector2 mDir, mUDir, mVDir;
        private float mSize;


        public ShowVector(Vector2 startPos, Vector2 dir, Vector2 uDir, Vector2 vDir, float size) {
            mDir = dir;
            mSize = size;

            mUDir = uDir;
            mVDir = vDir;

            mVec = new XNACS1Rectangle();
            mVecInU = new XNACS1Rectangle();
            mVecInV = new XNACS1Rectangle();

            // Create last to show on top!
            mStart = new XNACS1Circle(startPos, kVecWidth / 3);
            mStart.Color = Color.Red;

            UpdateEndPoints();
        }

        public void SetStartPos(Vector2 pos) 
        {
            mStart.Center = pos;
            UpdateEndPoints();
        }

        public void SetVectorSize(float s)
        {
            mSize = s;
            UpdateEndPoints();

        }

        public void SetVectorDir(Vector2 dir)
        {
            mDir = Vector2.Normalize(dir);
            UpdateEndPoints();
        }

        public void RemoveAllFromDraw()
        {
            mStart.RemoveFromAutoDrawSet();
            mVec.RemoveFromAutoDrawSet();
            mVecInU.RemoveFromAutoDrawSet();
            mVecInV.RemoveFromAutoDrawSet();
        }

        public Vector2 GetVectorStartPos()
        {
            return mStart.Center;
        }

        public Vector2 GetVectorEndPos()
        {
            return mStart.Center + (mSize * mDir);
        }

        public Vector2 GetVectorDir()
        {
            return mDir;
        }
        public float GetVectorSize()
        {
            return mSize;
        }

        public void FinalizeVector()
        {
            mVecInU.RemoveFromAutoDrawSet();
            mVecInV.RemoveFromAutoDrawSet();
        }

        private void UpdateEndPoints()
        {
            Vector2 delta = mSize * mDir;
            mVec.SetEndPoints(mStart.Center, mStart.Center + delta, kVecWidth);
            mVecInU.SetEndPoints(mStart.Center, (mStart.Center + mSize*mUDir), kVecWidth);
            mVecInV.SetEndPoints(mStart.Center, (mStart.Center + mSize*mVDir), kVecWidth);
            mVec.Color = kVecColor;
            mVecInU.Color = kUVecColor;
            mVecInV.Color = kVVecColor;
        }
    }
}
